@@ -23,22 +23,29 @@ class Infiniband(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
 
     plugin_name = 'infiniband'
     profiles = ('hardware',)
-    packages = ('libibverbs-utils',)
+    packages = ('libibverbs-utils', 'opensm', 'rdma', 'infiniband-diags')
 
     def setup(self):
         self.add_copy_spec([
             "/etc/ofed/openib.conf",
-            "/etc/ofed/opensm.conf"
+            "/etc/ofed/opensm.conf",
+            "/etc/rdma"
         ])
 
+        self.add_copy_spec("/var/log/opensm*",
+                           sizelimit=self.get_option("log_size"))
+
         self.add_cmd_output([
             "ibv_devices",
             "ibv_devinfo",
             "ibstat",
             "ibstatus",
-            "ibhosts"
+            "ibhosts",
+            "iblinkinfo",
+            "sminfo",
+            "perfquery"
         ])
 
         return
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
