@@ -23,16 +23,36 @@ from sos.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
 class OpenStackSwift(Plugin):
     """OpenStack Swift"""
     plugin_name = "openstack_swift"
-    profiles = ('openstack',)
+    profiles = ('openstack', 'openstack_controller')
 
-    option_list = [("log", "gathers openstack-swift logs", "slow", False)]
+    option_list = []
 
     def setup(self):
-        # Swift
+
+        self.limit = self.get_option("log_size")
+        if self.get_option("all_logs"):
+            self.add_copy_spec("/var/log/swift/", sizelimit=self.limit)
+        else:
+            self.add_copy_spec("/var/log/swift/*.log", sizelimit=self.limit)
+
         self.add_copy_spec("/etc/swift/")
 
+        if self.get_option("verify"):
+            self.add_cmd_output("rpm -V %s" % ' '.join(packages))
 
-class DebianOpenStackSwift(OpenStackSwift, DebianPlugin, UbuntuPlugin):
+    def postproc(self):
+        protect_keys = [
+            "ldap_dns_password", "neutron_admin_password", "rabbit_password",
+            "qpid_password", "powervm_mgr_passwd", "virtual_power_host_pass",
+            "xenapi_connection_password", "password", "host_password",
+            "vnc_password", "connection", "sql_connection", "admin_password"
+        ]
+
+        regexp = r"((?m)^\s*(%s)\s*=\s*)(.*)" % "|".join(protect_keys)
+        self.do_path_regex_sub("/etc/swift/.*\.conf.*", regexp, r"\1*********")
+
+
+class DebianSwift(OpenStackSwift, DebianPlugin, UbuntuPlugin):
 
     packages = (
         'swift',
@@ -46,7 +66,7 @@ class DebianOpenStackSwift(OpenStackSwift, DebianPlugin, UbuntuPlugin):
     )
 
 
-class RedHatOpenStackSwift(OpenStackSwift, RedHatPlugin):
+class RedHatSwift(OpenStackSwift, RedHatPlugin):
 
     packages = (
         'openstack-swift',
@@ -58,4 +78,4 @@ class RedHatOpenStackSwift(OpenStackSwift, RedHatPlugin):
         'python-swiftclient'
     )
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
