@@ -42,4 +42,6 @@ class Openswan(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
         if self.get_option("ipsec-barf"):
             self.add_cmd_output("ipsec barf")
 
-# vim: et ts=4 sw=4
+        self.add_forbidden_path("/etc/ipsec.d/key[3-4].db")
+
+# vim: set et ts=4 sw=4 :
